pub enum AnySource {
Register1(Register1),
Immediate1(Immediate1),
AbsoluteStack(AbsoluteStack),
RelativeStack(RelativeStack),
AdvanceStackPointer(AdvanceStackPointer),
CodePage(CodePage),
}Expand description
All supported addressing modes for the first source argument.
Variants
Register1(Register1)
Register mode.
Immediate1(Immediate1)
Immediate mode.
AbsoluteStack(AbsoluteStack)
Absolute stack addressing.
RelativeStack(RelativeStack)
Relative stack addressing.
AdvanceStackPointer(AdvanceStackPointer)
Relative stack addressing that updates the stack pointer on access.
CodePage(CodePage)
Addressing into the code page of the executing contract.